# GOSTRocks
Geospatial tools from the World Bank GOST team (mostly Ben).

# Installation
```
$ pip install GOSTRocks
```

Future releases and information can be built from the setup.py here, but pip will contain the most recent stable version

# Examples
...see the notebooks in the github repo
